@@ -1,16 +1,16 @@
 ;(function(){
   var map = {
-  "commitId": "b32683c59914f4a26fc4ae8848494ad58b949282",
-  "branchName": "release-client-6.2.1",
-  "buildTime": "2024-09-23 12:14:36 GMT",
-  "buildVersion": "1.0.1011",
+  "commitId": "bfcde5a01074b9698bdc62b86b1c8df9ca2dabee",
+  "branchName": "release-client-6.2.x",
+  "buildTime": "2024-11-18 06:03:11 GMT",
+  "buildVersion": "1.0.1326",
   "css": [
     "@zoom/client-scheduler/static/css/chunk-vendors.b08a77b8.css",
     "@zoom/client-scheduler/static/css/index.60f74ba0.css"
   ],
   "js": [
-    "@zoom/client-scheduler/chunk-vendors.555e0ea49113c8a3fd64.js",
-    "@zoom/client-scheduler/index.555e0ea49113c8a3fd64.js"
+    "@zoom/client-scheduler/chunk-vendors.e689e0ca0cca45d0985b.js",
+    "@zoom/client-scheduler/index.e689e0ca0cca45d0985b.js"
   ],
   "key": "clientSchedulerResource"
 };
